@@ -27,7 +27,7 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Henryhaoson"
     author_url = "https://github.com/Henryhaoson/sentry-dingtalk"
-    version = "2.0.1"
+    version = "2.0.2"
     resource_links = [
         ("Report Issue", "https://github.com/Henryhaoson/sentry-dingtalk/issues"),
         ("View Source", "https://github.com/Henryhaoson/sentry-dingtalk"),
@@ -82,11 +82,12 @@ class DingTalkPlugin(CorePluginMixin, notify.NotificationPlugin):
         user = event.get_minimal_user
         user_id = user.id
         environment = event.get_environment
+        release = event.release
         group = event.group
         project = group.project
         self._post(group, user_id, environment, release, project)
 
-    def _post(self, group, userId,,environment, release, project):
+    def _post(self, group, userId, environment, release, project):
         webhook = self.get_option("webhook", project)
         ats_str = self.get_option("ats", project)
         ats_array = ats_str.split(",")
